<?php
// Twitter Widget
class widget_thb_twitterwidget extends WP_Widget {
	function __construct() {
		$widget_ops = array(
			'classname'   => 'widget_thb_twitterwidget',
			'description' => esc_html__( 'Display your Tweets', 'werkstatt' ),
		);

		parent::__construct(
			'thb_thb_twitterwidget_widget',
			esc_html__( 'Fuel Themes - Twitter', 'werkstatt' ),
			$widget_ops
		);

		$this->defaults = array(
			'title'    => 'Twitter',
			'show'     => '3',
			'username' => 'fuel_themes',
		);
	}

	function widget( $args, $instance ) {
		$params = array_merge( $this->defaults, $instance );

		$tweets = thb_gettweets( $params['show'], $params['username'] );
		if ( array_key_exists( 'errors', $tweets ) ) {
			echo esc_html( $tweets['errors'][0]['message'] );
			return;
		}
		$twitter_data = thb_twitter_data( $tweets );

		// Before Widget.
		echo $args['before_widget'];

		// Title.
		if ( $params['title'] ) {
			echo wp_kses_post( $args['before_title'] . apply_filters( 'widget_title', $params['title'], $instance, $this->id_base ) . $args['after_title'] );
		}

		foreach ( $twitter_data['tweets'] as $tweet ) {
			?>
			<div class="thb_tweet">
				<p><?php echo wp_kses_post( $tweet['text'] ); ?></p>
				<a href="https://twitter.com/<?php echo esc_html( $twitter_data['screen_name'] ); ?>/status/<?php echo esc_attr( $tweet['id'] ); ?>" target="_blank" class="thb_tweet_time"><?php echo esc_html( $tweet['time'] ); ?></a>
			</div>
			<?php
		}
		echo $args['after_widget'];
	}
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		return $instance;
	}
	function form( $instance ) {
		$params = array_merge( $this->defaults, $instance );
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Widget Title:', 'werkstatt' ); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $params['title'] ); ?>" class="widefat" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>"><?php esc_html_e( 'Number of Tweets:', 'werkstatt' ); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show' ) ); ?>" value="<?php echo esc_attr( $params['show'] ); ?>" class="widefat" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>"><?php esc_html_e( 'Username:', 'werkstatt' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'username' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'username' ) ); ?>" type="text" value="<?php echo esc_attr( $params['username'] ); ?>" />
		</p>
		<?php
	}
}
